// MVS5603 CANbus API V1.3 2017/12/28
#define MVS5603_CAN_API extern "C" __declspec(dllimport)


typedef enum
{
	CAN_BAUD_12500   = 0,  // 12.5  kbps
	CAN_BAUD_16000   = 1,  // 16    kbps
	CAN_BAUD_20000   = 2,  // 20    kbps
	CAN_BAUD_25000   = 3,  // 25    kbps
	CAN_BAUD_31250   = 4,  // 31.25 kbps
	CAN_BAUD_40000   = 5,  // 40    kbps
	CAN_BAUD_50000   = 6,  // 50    kbps
	CAN_BAUD_62500   = 7,  // 62.5  kbps
	CAN_BAUD_80000   = 8,  // 80    kbps
	CAN_BAUD_100000  = 9,  // 100   kbps
	CAN_BAUD_125000  = 10, // 125   kbps
	CAN_BAUD_200000  = 11, // 200   kbps
	CAN_BAUD_250000  = 12, // 250   kbps
	CAN_BAUD_400000  = 13, // 400   kbps
	CAN_BAUD_500000  = 14, // 500   kbps
	CAN_BAUD_1000000 = 15  // 1000  kbps
} can_baud_t;


typedef struct can_filter 
{
	unsigned short num;		// Filter number (0~13)
	unsigned int   id;		// ID
	unsigned int   mid;		// Mask ID
	unsigned short mode;	// Filter Mode (mask mode or list mode)
	unsigned short scale;	// Filter Scale (Two 16-bit filters or One 32-bit filter)
	unsigned short act;		// Filter Activation (Disable or Enable)
} can_filter_t;


#define CAN_MSG_DATA_LEN	(8)				// CAN Msg data length

typedef struct can_msg
{
	unsigned short ide;						// Standard/extended msg
	unsigned int   id;						// 11 or 29 bit msg id
	unsigned short dlc;						// Size of data
	unsigned char  data[CAN_MSG_DATA_LEN];	// Message pay load
	unsigned short rtr;						// RTR message
} can_msg_t;


MVS5603_CAN_API void CAN_Get_DLL_Version(int *pnMajorVersion, int *pnMinorVersion);

MVS5603_CAN_API int  CAN_Connect();
MVS5603_CAN_API void CAN_Disconnect();

MVS5603_CAN_API int  CAN_SetCANSpeed(int nCANSpeed);

MVS5603_CAN_API int  CAN_SetCANFilter(can_filter_t *pFilter);

MVS5603_CAN_API int  CAN_SetCANSendMessage(can_msg_t *pMSG);
MVS5603_CAN_API int  CAN_SetCANStopTransmit();

MVS5603_CAN_API int  CAN_Receive(can_msg_t *pMSG);
MVS5603_CAN_API int  CAN_Receive_Wait(can_msg_t *pMSG, DWORD dwMilliseconds);
MVS5603_CAN_API int  CAN_Receive_Block(can_msg_t *pMSG);

MVS5603_CAN_API int  CAN_SetCANClearReceiveFIFO();

MVS5603_CAN_API int  CAN_GetCANErrorCode(unsigned char *pbyErrorCode);
